///**
// * BNSim is an open-source, parallel, stochastic, and multi-scale modeling
// * platform which integrates various simulation algorithms, together with
// * genetic circuits and chemotaxis pathway models in a 3D environment.
// *
// * BNSim is developed by CMU SLD Group, and released under GPLv2 license
// * Please check http://www.ece.cmu.edu/~sld/bnsim for more information
// *
// * BNSim is developed using C++ and pthread under Linux and Mac OS
// *
// * If you use it for your work, please cite
// * Wei, Guopeng, Paul Bogdan, and Radu Marculescu. "Efficient Modeling and
// * Simulation of Bacteria-Based Nanonetworks with BNSim." Selected Areas in
// * Communications, IEEE Journal on 31.12 (2013): 868-878.
// *
// * @author      Guopeng (Daniel) Wei  danielwei@cmu.edu
// * @version     2.5
// * @since       1.0
// */
//
//#include "../core/core.h"
//#include <cstring>
//
//using namespace std;
//using namespace BNSim;
//
//
//int main(int argn, char ** argv) {
//
//	// setup the environment
//
//	Sim::param.WorldSize = new myVector3d(1000,1000,100);
//	Sim::param.cubeNumber.x = Sim::param.cubeNumber.y = 50;
//	Sim::param.cubeNumber.z = 4;
//	Sim::param.ThreadNumber = 4;
//	Sim::param.ChemicalNumber = 1;
//    Sim::param.quorumSensing = true;
//    Sim::param.chemotaxis = false;
//    Sim::param.workdir = "/Users/guopengwei/Documents/QStest";
//    Sim::param.bacteriaRadius = 2;
//	Sim::param.bacNum= 4000;
//
//     for (int i=1; i<argn; i++) {
//
//            if (strcmp(argv[i], "-directory") == 0) {
//                Sim::param.workdir = argv[++i];
//                continue;
//            }
//
//            if (strcmp(argv[i], "-bacNum") == 0) {
//                if (!sscanf(argv[++i], "%d", &Sim::param.bacNum)) {
//                        return 1;
//                }
//                continue;
//            }
//     }
//
//    cout<<"Configuring environment..."<<endl;
//
//	Universe * myuniv =  new Universe();
//	Sim::univ = myuniv;
//
//	// adding chemicals
//
//	Sim::chemical.push_back(chemicalSpecies());
//	Sim::chemical[0].diffusionCoefficient = 890;
//	Sim::chemical[0].degradationRate = 0.01;
//	Sim::chemical[0].name = "AI";
//
//	// adding bacteria
//	cout<<"Adding bacteria..."<<endl;
//
//	double velocity = 4;
//
//	for(int i = 0; i != Sim::param.bacNum; ++i) {
//		myVector3d Position;
//		Position.pos.x = 0.05*Sim::param.WorldSize->pos.x + 0.9*Sim::param.WorldSize->pos.x*((double) rand() / (RAND_MAX));
//		Position.pos.y = 0.05*Sim::param.WorldSize->pos.x + 0.9*Sim::param.WorldSize->pos.y*((double) rand() / (RAND_MAX));
//		Position.pos.z = 0.05*Sim::param.WorldSize->pos.x + 0.9*Sim::param.WorldSize->pos.z*((double) rand() / (RAND_MAX));
//
//		Bacteria* bac = new Bacteria(Position, Sim::param.bacteriaRadius, velocity, i);
//		// Two bacteria cannot occupy the same place
//		if(bac->intersect()) {
//			delete bac; i--;
//		}
//		else {
//            myuniv->addBacteria(bac);
//            bac->registerinCube(myuniv->getCube(bac->getCubeLoc()),bac->getCurrentCubeRelativeIndex());
//		}
//	}
//
//	Sim::univ->prepare_multithreading();
//
//	int dumpStep = 0;
//
//    char file_name[100];
//    int clk= (int)Sim::param.time;
//    string path = Sim::param.workdir + "/PopAVG.txt";
//    sprintf(file_name, path.c_str() ,clk);
//    ofstream bac(file_name);
//
//    exporter::dump_Gradient(0);
//    cout<<"Simulation Start"<<endl;
//
//
//	// Main simulation loop
//	for(;Sim::param.time<10000000000;Sim::param.time+=Sim::param.timeStep,dumpStep++) {
//		myuniv->tick();
//
//	
//		if(dumpStep == 1000) {
//            double AC1 = 0, AR1 = 0, AA1 = 0;
//
//            for(int i = 0; i != Sim::param.bacNum; ++i) {
//                Bacteria * bacterium = myuniv->getBacteria(i);
//                AA1+=bacterium->getQS()->getA1();
//                AR1+=bacterium->getQS()->getR1();
//                AC1+=bacterium->getQS()->getC1();
//            }
//
//            AA1  = AA1/Sim::param.bacNum;
//            AR1  = AR1/Sim::param.bacNum;
//            AC1  = AC1/Sim::param.bacNum;
//
//            bac<<(int)Sim::param.time<<" "<<AA1<<" "<<AR1<<" "<<AC1<<endl;
//			dumpStep = 0;
//            exporter::dump_Gradient(0);
//		}
//
//		cout<<"Simulation time: "<< Sim::param.time << " s"<<endl;
//	}
//
//	exporter::dump_Gradient(0);
//
//	delete myuniv;
//
//	return 0;
//}
